@@ -5,7 +5,6 @@
 
 import collections
 import contextlib
-import glob
 import os
 import os.path
 import re
@@ -16,6 +15,9 @@ import warnings
 
 from unittest import mock
 
+import pytest
+
+from coverage import env
 from coverage.exceptions import CoverageWarning
 from coverage.misc import output_encoding
 
@@ -170,12 +172,6 @@ def re_line(pat, text):
     return lines[0]
 
 
-def remove_files(*patterns):
-    """Remove all files that match any of the patterns."""
-    for pattern in patterns:
-        for fname in glob.glob(pattern):
-            os.remove(fname)
-
 def remove_tree(dirname):
     """Remove a directory tree.
 
@@ -320,3 +316,14 @@ def swallow_warnings(message=r".", category=CoverageWarning):
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", category=category, message=message)
         yield
+
+
+xfail_pypy_3749 = pytest.mark.xfail(
+    env.PYVERSION[:2] == (3, 8) and env.PYPY and env.PYPYVERSION >= (7, 3, 10),
+    reason="Avoid a PyPy bug: https://foss.heptapod.net/pypy/pypy/-/issues/3749",
+)
+
+xfail_pypy_3792 = pytest.mark.xfail(
+    env.PYBEHAVIOR.report_absolute_files and env.PYPY,
+    reason="Avoid a PyPy bug: https://foss.heptapod.net/pypy/pypy/-/issues/3792",
+)
