@@ -19,7 +19,7 @@ from coverage.data import line_counts
 from coverage.files import abs_file, python_reported_file
 
 from tests.coveragetest import CoverageTest, TESTS_DIR
-from tests.helpers import re_lines_text
+from tests.helpers import re_lines_text, xfail_pypy_3792
 
 
 class ProcessTest(CoverageTest):
@@ -283,6 +283,7 @@ class ProcessTest(CoverageTest):
         assert "rror" not in out
         assert status == 1
 
+    @xfail_pypy_3792    # Because the file names aren't yet absolute.
     def test_code_throws(self):
         self.make_file("throw.py", """\
             class MyException(Exception):
@@ -302,7 +303,7 @@ class ProcessTest(CoverageTest):
         status, out = self.run_command_status("coverage run throw.py")
         out2 = self.run_command("python throw.py")
         if env.PYPY:
-            # Pypy has an extra frame in the traceback for some reason
+            # PyPy has an extra frame in the traceback for some reason
             out2 = re_lines_text("toplevel", out2, match=False)
         assert out == out2
 
@@ -552,10 +553,6 @@ class ProcessTest(CoverageTest):
     @pytest.mark.expensive
     @pytest.mark.skipif(not env.C_TRACER, reason="fullcoverage only works with the C tracer.")
     @pytest.mark.skipif(env.METACOV, reason="Can't test fullcoverage when measuring ourselves")
-    @pytest.mark.xfail(
-        (3, 11, 0, "alpha", 4) <= env.PYVERSION,
-        reason="avoid 3.11 bug lineno==None: https://bugs.python.org/issue46389",
-    )
     def test_fullcoverage(self):
         # fullcoverage is a trick to get stdlib modules measured from
         # the very beginning of the process. Here we import os and
@@ -699,6 +696,7 @@ class EnvironmentTest(CoverageTest):
         actual = self.run_command("coverage run -m process_test.try_execfile")
         self.assert_tryexecfile_output(expected, actual)
 
+    @xfail_pypy_3792    # Because the sys.path[0] isn't yet absolute.
     def test_coverage_run_dir_is_like_python_dir(self):
         with open(TRY_EXECFILE) as f:
             self.make_file("with_main/__main__.py", f.read())
@@ -830,7 +828,7 @@ class EnvironmentTest(CoverageTest):
             sys.path[0:0] = [
                 r'{abc}',
                 '/Users/somebody/temp/something/eggs/something-4.5.1-py2.7-xxx-10.13-x86_64.egg',
-                ]
+            ]
 
             import coverage.cmdline
 
@@ -1080,7 +1078,7 @@ class FailUnderTest(CoverageTest):
             "b = 2\n" * 2000 +
             "if a > 3:\n" +
             "    c = 4\n"
-            )
+        )
         self.make_data_file(lines={abs_file("ninety_nine_plus.py"): range(1, 2002)})
         st, out = self.run_command_status("coverage report --fail-under=100")
         assert st == 2
